@@ -295,11 +295,13 @@ if (Sentry === undefined) {
         var vars = {}, hash;
         var href = window.location.href;
         var hashes = href.slice(href.indexOf('?') + 1, (href.indexOf('#') !== -1 ? href.indexOf('#') : href.length)).split('&');
-        for(var i = 0; i < hashes.length; i++)
-        {
-            hash = hashes[i].split('=');
-            vars[hash[0]] = decodeURIComponent(hash[1]).replace(/\+/, ' ');
-        }
+        $.each(hashes, function(_, chunk){
+            hash = chunk.split('=');
+            if (!hash[0] && !hash[1]) {
+              return;
+            }
+            vars[hash[0]] = hash[1] ? decodeURIComponent(hash[1]).replace(/\+/, ' ') : '';
+        });
         return vars;
     };
 
