@@ -5,6 +5,7 @@ sentry.web.views
 :copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+import datetime
 import logging
 
 from django.core.urlresolvers import reverse
@@ -138,11 +139,11 @@ def store(request, project_id=None):
 
             insert_data_to_database(data)
         except APIError, error:
-            logging.error('Client %r raised API error: %s' % (client, error), exc_info=True)
+            logger.error('Client %r raised API error: %s' % (client, error), exc_info=True)
             response = HttpResponse(unicode(error.msg), status=error.http_status)
         else:
             if request.method == 'POST':
-                logging.info('New event from client %r (id=%%s)' % client, data['event_id'])
+                logger.info('New event from client %r (id=%%s)' % client, data['event_id'])
             response = HttpResponse('')
     else:
         # OPTIONS
@@ -219,8 +220,14 @@ def resolve(request, project):
     except Group.DoesNotExist:
         return HttpResponseForbidden()
 
-    Group.objects.filter(pk=group.pk).update(status=1)
+    now = datetime.datetime.now()
+
+    Group.objects.filter(pk=group.pk).update(
+        status=1,
+        resolved_at=now,
+    )
     group.status = 1
+    group.resolved_at = now
 
     data = [
         (m.pk, {
